@@ -2,6 +2,9 @@
 
 '''
 '''
+from __future__ import print_function
+from __future__ import absolute_import
+from builtins import range
 
 __docformat__ = 'restructuredtext'
 __version__ = '$Id: $'
@@ -12,9 +15,9 @@ import pyglet
 from pyglet.libs.darwin import carbon, _oscheck, create_cfstring
 from pyglet.libs.darwin.constants import *
 
-from base import Device, Control, AbsoluteAxis, RelativeAxis, Button
-from base import Joystick, AppleRemote
-from base import DeviceExclusiveException
+from .base import Device, Control, AbsoluteAxis, RelativeAxis, Button
+from .base import Joystick, AppleRemote
+from .base import DeviceExclusiveException
 
 # non-broken c_void_p
 void_p = ctypes.POINTER(ctypes.c_int)
@@ -253,7 +256,7 @@ def get_property(properties, key):
 
 def dump_properties(properties):
     def func(key, value, context):
-        print '%s = %s' % (cfstring_to_string(key), cfvalue_to_value(value))
+        print('%s = %s' % (cfstring_to_string(key), cfvalue_to_value(value)))
     CFDictionaryApplierFunction = ctypes.CFUNCTYPE(None, 
         ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p)
     carbon.CFDictionaryApplyFunction(properties,
@@ -363,7 +366,7 @@ class DarwinHIDDevice(Device):
             r = self._queue.contents.contents.addElement(self._queue,
                                                          control._cookie, 0)
             if r != 0:
-                print 'error adding %r' % control
+                print('error adding %r' % control)
 
         self._event_source = CFRunLoopSourceRef()
         self._queue_callback_func = IOHIDCallbackFunction(self._queue_callback)
@@ -424,7 +427,7 @@ class DarwinHIDDevice(Device):
         while r == 0:
             try:
                 control = self._control_cookies[event.elementCookie]
-                control._set_value(event.value)
+                control.value = event.value
             except KeyError:
                 pass
 
@@ -505,8 +508,12 @@ def get_devices(display=None):
     return [DarwinHIDDevice(display, service) for service in services]
 
 def get_joysticks(display=None):
-    return filter(None, 
-        [_create_joystick(device) for device in get_devices(display)])
+    return [joystick 
+            for joystick 
+            in [_create_joystick(device) 
+                for device 
+                in get_devices(display)] 
+            if joystick is not None]
 
 def get_apple_remote(display=None):
     for device in get_devices(display):
